@@ -3,11 +3,13 @@ package CPANPLUS::Dist::Slackware::PackageDescription;
 use strict;
 use warnings;
 
-our $VERSION = '1.024';
+our $VERSION = '1.025';
 
 use English qw( -no_match_vars );
 
-use File::Spec qw();
+use CPANPLUS::Dist::Slackware::Util qw(catdir catfile tmpdir);
+
+use Config;
 use File::Temp qw();
 use Module::CoreList qw();
 use Pod::Find qw();
@@ -38,6 +40,12 @@ sub _normalize_name {
     if ( $name !~ /^perl-/ ) {
         $name = 'perl-' . $name;
     }
+
+    # Prepend "c" if the package is built for cperl.
+    if ( defined $Config{'usecperl'} ) {
+        $name = 'c' . $name;
+    }
+
     return $name;
 }
 
@@ -128,7 +136,7 @@ sub filename {
 
 sub outputdir {
     my $self = shift;
-    return $self->{outputdir} || $ENV{OUTPUT} || File::Spec->tmpdir;
+    return $self->{outputdir} || $ENV{OUTPUT} || tmpdir();
 }
 
 sub outputname {
@@ -136,7 +144,7 @@ sub outputname {
     my $outputname = $self->filename;
     my $outputdir  = $self->outputdir;
     if ($outputdir) {
-        $outputname = File::Spec->catfile( $outputdir, $outputname );
+        $outputname = catfile( $outputdir, $outputname );
     }
     return $outputname;
 }
@@ -144,7 +152,7 @@ sub outputname {
 sub docdir {
     my $self = shift;
     return $self->{docdir}
-        || File::Spec->catfile( '/usr/doc', $self->distname );
+        || catfile( $Config{prefix}, 'doc', $self->distname );
 }
 
 sub docfiles {
@@ -154,7 +162,7 @@ sub docfiles {
     my $wrksrc = $module->status->extract;
     return if !$wrksrc;
 
-    opendir my $dh, $wrksrc or return;
+    opendir(my $dh, $wrksrc) or return;
     my @docfiles = grep {
         m{ ^(?:
                 AUTHORS
@@ -169,7 +177,7 @@ sub docfiles {
                 | THANKS
                 | TODO
             )$
-        }xi && -f File::Spec->catfile( $wrksrc, $_ )
+        }xi && -f catfile( $wrksrc, $_ )
     } readdir $dh;
     closedir $dh;
     return @docfiles;
@@ -185,9 +193,7 @@ sub _summary_from_pod {
 
     my $summary = q{};
     my @dirs    = (
-        map { File::Spec->catdir( $wrksrc, $_ ) }
-            qw(blib/lib blib/bin lib bin),
-        $wrksrc
+        map { catdir( $wrksrc, $_ ) } qw(blib/lib blib/bin lib bin), $wrksrc
     );
     my $podfile = Pod::Find::pod_where( { -dirs => \@dirs }, $srcname );
     if ($podfile) {
@@ -216,7 +222,7 @@ sub _summary_from_meta {
 
     my $summary = q{};
     for (qw(META.yml META.json)) {
-        my $metafile = File::Spec->catfile( $wrksrc, $_ );
+        my $metafile = catfile( $wrksrc, $_ );
         if ( -f $metafile ) {
             my $distmeta;
             eval { $distmeta = Parse::CPAN::Meta::LoadFile($metafile) }
@@ -466,8 +472,7 @@ sub destdir {
     my $destdir = $self->{destdir};
     if ( !$destdir ) {
         my $template = 'package-' . $self->normalized_name . '-XXXXXXXXXX';
-        my $wrkdir   = $ENV{TMP}
-            || File::Spec->catdir( File::Spec->tmpdir, 'CPANPLUS' );
+        my $wrkdir = $ENV{TMP} || catdir( tmpdir(), 'CPANPLUS' );
         if ( !-d $wrkdir ) {
             $cb->_mkdir( dir => $wrkdir )
                 or die "Could not create directory '$wrkdir': $OS_ERROR\n";
@@ -489,7 +494,7 @@ CPANPLUS::Dist::Slackware::PackageDescription - Collect information on a new Sla
 
 =head1 VERSION
 
-This document describes CPANPLUS::Dist::Slackware::PackageDescription version 1.024.
+This document describes CPANPLUS::Dist::Slackware::PackageDescription version 1.025.
 
 =head1 SYNOPSIS
 
@@ -651,9 +656,7 @@ See above and CPANPLUS::Dist::Slackware for supported environment variables.
 
 =head1 DEPENDENCIES
 
-Requires the modules File::Spec, File::Temp, Pod::Find, Pod::Simple, POSIX,
-Text::Wrap, and version 0.77.  If available, the module Parse::CPAN::Meta is
-used.
+See CPANPLUS::Dist::Slackware.
 
 =head1 INCOMPATIBILITIES
 
@@ -674,7 +677,7 @@ through the web interface at L<http://rt.cpan.org/>.
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2012-2016 Andreas Voegele
+Copyright 2012-2017 Andreas Voegele
 
 This library is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
